@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf - 8 -* -
 from refinery.units import Unit
-from refinery.lib.vfs import VirtualFileSystem, VirtualFile
+from refinery.lib.vfs import VirtualFileSystem
 
 
 class evtx(Unit):
@@ -10,7 +10,7 @@ class evtx(Unit):
     output chunk in XML format.
     """
 
-    def __init__(self, raw: Unit.Arg.switch('-r', help='Extract raw event data rather than XML.') = False):
+    def __init__(self, raw: Unit.Arg.Switch('-r', help='Extract raw event data rather than XML.') = False):
         super().__init__(raw=raw)
 
     @Unit.Requires('python-evtx')
@@ -21,6 +21,6 @@ class evtx(Unit):
     def process(self, data):
         with VirtualFileSystem() as vfs:
             raw = self.args.raw
-            with self._evtx(VirtualFile(vfs, data)) as log:
+            with self._evtx(vfs.new(data)) as log:
                 for record in log.records():
                     yield record.data() if raw else record.xml().encode(self.codec)
